#############################################################
#
# alsa-lib
#
#############################################################
ALSA_LIB_VER:=1.0.9
ALSA_LIB_SOURCE:=alsa-lib-$(ALSA_LIB_VER).tar.bz2
ALSA_LIB_SITE:=ftp://ftp.alsa-project.org/pub/lib
ALSA_LIB_CAT:=bzcat
ALSA_LIB_DIR:=$(BUILD_DIR)/alsa-lib-$(ALSA_LIB_VER)
ALSA_LIB_BINARY:=libasound.so.2.0.0

$(DL_DIR)/$(ALSA_LIB_SOURCE):
	 $(WGET) -P $(DL_DIR) $(ALSA_LIB_SITE)/$(ALSA_LIB_SOURCE)

alsa-lib-source: $(DL_DIR)/$(ALSA_LIB_SOURCE)

$(ALSA_LIB_DIR)/.unpacked: $(DL_DIR)/$(ALSA_LIB_SOURCE)
	$(ALSA_LIB_CAT) $(DL_DIR)/$(ALSA_LIB_SOURCE) | tar -C $(BUILD_DIR) $(TAR_OPTIONS) -
	toolchain/patch-kernel.sh $(ALSA_LIB_DIR) local/alsa-lib/patches/ '*'
	touch $(ALSA_LIB_DIR)/.unpacked

$(ALSA_LIB_DIR)/.configured: $(ALSA_LIB_DIR)/.unpacked
	(cd $(ALSA_LIB_DIR); rm -rf config.cache; \
		$(TARGET_CONFIGURE_OPTS) CC_FOR_BUILD=$(HOSTCC) \
		CFLAGS="$(TARGET_CFLAGS)" \
		LDFLAGS="-L$(STAGING_DIR)/lib" \
		./configure \
		--target=$(GNU_TARGET_NAME) \
		--host=$(GNU_TARGET_NAME) \
		--build=$(GNU_HOST_NAME) \
		--prefix=/usr \
		--exec-prefix=/usr \
		--bindir=/usr/bin \
		--sbindir=/usr/sbin \
		--libexecdir=/usr/lib \
		--sysconfdir=/etc \
		--datadir=/usr/share \
		--localstatedir=/var \
		--mandir=/usr/man \
		--infodir=/usr/info \
		--with-softfloat \
		--enable-shared=yes \
		--enable-static=no \
	);
	touch  $(ALSA_LIB_DIR)/.configured

$(ALSA_LIB_DIR)/src/.libs/$(ALSA_LIB_BINARY): $(ALSA_LIB_DIR)/.configured
	$(MAKE) CC=$(TARGET_CC) CC_FOR_BUILD=$(HOSTCC) -C $(ALSA_LIB_DIR)

$(STAGING_DIR)/usr/lib/$(ALSA_LIB_BINARY): \
		$(ALSA_LIB_DIR)/src/.libs/$(ALSA_LIB_BINARY)
	$(MAKE) DESTDIR=$(STAGING_DIR) CC=$(TARGET_CC) -C $(ALSA_LIB_DIR) install

$(TARGET_DIR)/usr/lib/$(ALSA_LIB_BINARY): \
	$(STAGING_DIR)/usr/lib/$(ALSA_LIB_BINARY)
	cp -dpf $(STAGING_DIR)/usr/bin/$(GNU_TARGET_NAME)-alsalisp $(TARGET_DIR)/usr/bin/alsalisp
	cp -dpf $(STAGING_DIR)/usr/bin/$(GNU_TARGET_NAME)-aserver $(TARGET_DIR)/usr/bin/aserver
	cp -dpf $(STAGING_DIR)/usr/lib/libasound.so* $(TARGET_DIR)/usr/lib/
	-$(STRIP) --strip-unneeded $(TARGET_DIR)/usr/lib/libasound.so
	-$(STRIP) --strip-unneeded $(TARGET_DIR)/usr/bin/alsalisp
	-$(STRIP) --strip-unneeded $(TARGET_DIR)/usr/bin/aserver
	cp -dpfr $(STAGING_DIR)/usr/share/alsa $(TARGET_DIR)/usr/share

alsa-lib: uclibc $(TARGET_DIR)/usr/lib/$(ALSA_LIB_BINARY)

alsa-lib-clean:
	-make -C $(ALSA_LIB_DIR) clean

alsa-lib-dirclean:
	rm -rf $(ALSA_LIB_DIR)

#############################################################
#
# Toplevel Makefile options
#
#############################################################
ifeq ($(strip $(BR2_PACKAGE_ALSA_LIB)),y)
TARGETS+=alsa-lib
endif

