#############################################################
#
# boost
#
# This buildroot package was written by Claus Klein and came from
# http://uclibc.org/lists/buildroot/2006-November/000531.html
#
# I tweaked it slightly to remove the use of $(TARGET_CXX) which
# doesn't appear to be defined.
#
#############################################################

BOOST_VER:=1_33_1
BOOST_INCDIR_VER:=$(BOOST_VER)
BOOST_DIR:=$(BUILD_DIR)/boost_$(BOOST_VER)
BOOST_SITE:=http://$(BR2_SOURCEFORGE_MIRROR).dl.sourceforge.net/sourceforge/boost
BOOST_SOURCE:=boost_$(BOOST_VER).tar.bz2
BOOST_CAT:=bzcat

# usage: bjam [ options ] targets...
#
# -a      Build all targets, even if they are current.
# -dx     Set the debug level to x (0-9).
# -fx     Read x instead of Jambase.
# -jx     Run up to x shell commands concurrently.
# -n      Don't actually execute the updating actions.
# -ox     Write the updating actions to file x.
# -q      Quit quickly as soon as a target fails.
# -sx=y   Set variable x=y, overriding environment.
# -tx     Rebuild x, even if it is up-to-date.
# -v      Print the version of jam and exit.
# --x     Option is ignored.
#
# /scratch/buildroot/build_powerpc/boost_1_33_1> bjam --show-libraries
#	 regex signals serialization thread python filesystem wave date_time iostreams test program_options graph
# For example the default is to request "debug release <runtime-link>static/dynamic <threading>single/multi"
#
# -sNO_COMPRESSION=1  	Build Boost.Iostreams without support for the compression filters which rely on the
#  non-Boost libraries zlib and libbz2. If you use Windows, this option is enabled by default. If you use UNIX,
#  the compression filters will likely work with no configuration, so this option should not be necessary.
#  For full details see Boost.Iostreams Installation.

# -sHAVE_ICU=1  	Build Boost.Regex libraries with Unicode support provided by the ICU libraries.
#  ICU must have been built with the same compiler that you are using to build Boost, and must be installed
#  into your compiler's include and library search paths. See the Boost.Regex installation documentation
#  for more information.

# NO_BZIP2   Disable support for the bzip2 filters.
# ZLIB_INCLUDE   Path to the zlib headers, if they're not in a location where they'll be found automatically.   ZLIB_SOURCE
# ZLIB_LIBPATH   Path to the zlib binary, if it's not in a location where it will be found automatically.
# On Windows, if linking with a dynamic build of zlib, specify the path to the import library.   -
# ZLIB_SOURCE   Path to the zlib source files, if they're not in a location where they'll be found automatically.

###FIXME### -sZLIB_SOURCE=$(ZLIB_DIR) -sZLIB_INCLUDE=$(STAGING_DIR)/include -sZLIB_LIBPATH=$(STAGING_DIR)/lib \
###FIXME### -sBZIP2_SOURCE=$(BZIP2_DIR) -sBZIP2_INCLUDE=$(STAGING_DIR)/include -sBZIP2_LIBPATH=$(STAGING_DIR)/lib \
# -sNO_ZLIB=0 \
# -sNO_BZIP2=1 \

BOOST_JAM_FLAGS= -q -sTools=gcc \
 -sGCC_ROOT_DIRECTORY=$(STAGING_DIR) \
 -sGXX=$(TARGET_CC) \
 -sGCC=$(TARGET_CC) \
 -sBUILD="release <runtime-link>static <optimization>speed <threading>multi" \
 -sZLIB_SOURCE=$(ZLIB_DIR) \
 --with-iostreams \
 --with-filesystem \
 --with-thread \
 --with-signals \
 --with-zlib \
 --without-python


### \
 --without-serialization \
 --without-regex \

$(DL_DIR)/$(BOOST_SOURCE):
	 $(WGET) -P $(DL_DIR) $(BOOST_SITE)/$(BOOST_SOURCE)

boost-source: $(DL_DIR)/$(BOOST_SOURCE)

$(BOOST_DIR)/.unpacked: $(DL_DIR)/$(BOOST_SOURCE)
	$(BOOST_CAT) $(DL_DIR)/$(BOOST_SOURCE) | tar -C $(BUILD_DIR) $(TAR_OPTIONS) -
	toolchain/patch-kernel.sh $(BOOST_DIR) local/boost/ boost_$(BOOST_VER)\*.patch
	touch $@

$(BOOST_DIR)/.configured: $(BOOST_DIR)/.unpacked
	touch $@


$(BOOST_DIR)/bin/boost/libs/thread/build/libboost_thread.so: $(BOOST_DIR)/.configured
	cd $(BOOST_DIR); \
		bjam $(BOOST_JAM_FLAGS) \
		--prefix=$(STAGING_DIR) \

$(STAGING_DIR)/lib/libboost_thread-gcc-mt.so: $(BOOST_DIR)/bin/boost/libs/thread/build/libboost_thread.so
	cd $(BOOST_DIR); \
		bjam $(BOOST_JAM_FLAGS) \
		--prefix=$(STAGING_DIR) \
		install
	cd $(STAGING_DIR)/include; ln -sf boost-$(BOOST_INCDIR_VER)/boost

$(TARGET_DIR)/lib/libboost_thread-gcc-mt.so: $(BOOST_DIR)/bin/boost/libs/thread/build/libboost_thread.so
	cd $(BOOST_DIR); \
		bjam $(BOOST_JAM_FLAGS) \
		--prefix=$(TARGET_DIR) \
		--stagedir=$(TARGET_DIR) \
		stage

boost-dependancies:
	@if ! which bjam > /dev/null ; then \
		echo -e "\n\nYou must install 'bjam' on your build machine\n"; \
		echo -e "\t For more information on Boost.Jam visit the project homepage\n"; \
		echo -e "\t http://www.boost.org/tools/build/jam_src/ .\n"; \
		exit 1; \
	fi;

boost: boost-dependancies uclibc zlib bzip2 \
  $(STAGING_DIR)/lib/libboost_thread-gcc-mt.so \
   ###tbd### $(TARGET_DIR)/lib/libboost_thread-gcc-mt.so \

boost-clean:
	rm -rf $(STAGING_DIR)/include/boost*
	rm -f $(STAGING_DIR)/lib/libboost_*
	rm -f $(TARGET_DIR)/lib/libboost_*
	cd $(BOOST_DIR); \
		bjam $(BOOST_JAM_FLAGS) \
		clean

boost-dirclean:
	rm -rf $(BOOST_DIR)

#############################################################
#
# Toplevel Makefile options
#
#############################################################
ifeq ($(strip $(BR2_PACKAGE_BOOST)),y)
TARGETS+=boost
endif
