#############################################################
#
# netperf
#
#############################################################
NETPERF_VER:=2.4.3
NETPERF_SOURCE:=netperf-$(NETPERF_VER).tar.gz
NETPERF_SITE:=ftp://ftp.netperf.org/netperf/
NETPERF_CAT:=zcat
NETPERF_DIR:=$(BUILD_DIR)/netperf-$(NETPERF_VER)
NETPERF_BINARY:=netperf

$(DL_DIR)/$(NETPERF_SOURCE):
	 $(WGET) -P $(DL_DIR) $(NETPERF_SITE)/$(NETPERF_SOURCE)

netperf-source: $(DL_DIR)/$(NETPERF_SOURCE)

$(NETPERF_DIR)/.unpacked: $(DL_DIR)/$(NETPERF_SOURCE)
	$(NETPERF_CAT) $(DL_DIR)/$(NETPERF_SOURCE) | tar -C $(BUILD_DIR) $(TAR_OPTIONS) -
	touch $(NETPERF_DIR)/.unpacked

$(NETPERF_DIR)/.configured: $(NETPERF_DIR)/.unpacked
	(cd $(NETPERF_DIR); rm -rf config.cache; \
		$(TARGET_CONFIGURE_OPTS) \
        ac_cv_func_setpgrp_void=yes \
		CFLAGS="$(TARGET_CFLAGS)" \
		LDFLAGS="-L$(STAGING_DIR)/lib -L$(STAGING_DIR)/usr/local/lib -Wl,--rpath-link -Wl,$(STAGING_DIR)/usr/local/lib" \
		./configure \
		--target=$(GNU_TARGET_NAME) \
		--host=$(GNU_TARGET_NAME) \
		--build=$(GNU_HOST_NAME) \
		--prefix=/usr \
		--exec-prefix=/usr \
		--bindir=/usr/bin \
		--sbindir=/usr/sbin \
		--libexecdir=/usr/lib \
		--sysconfdir=/etc \
		--datadir=/usr/share \
		--localstatedir=/var \
		--mandir=/usr/man \
		--infodir=/usr/info \
		$(TARGET_CONFIGURE_FLAGS) \
	);
	touch  $(NETPERF_DIR)/.configured

$(NETPERF_DIR)/src/$(NETPERF_BINARY): $(NETPERF_DIR)/.configured
	$(MAKE) CC=$(TARGET_CC) -C $(NETPERF_DIR)

$(STAGING_DIR)/usr/bin/$(NETPERF_BINARY): $(NETPERF_DIR)/src/$(NETPERF_BINARY)
	$(MAKE) DESTDIR=$(STAGING_DIR) CC=$(TARGET_CC) -C $(NETPERF_DIR) install

$(TARGET_DIR)/usr/bin/$(NETPERF_BINARY): $(STAGING_DIR)/usr/bin/$(NETPERF_BINARY)
	cp -a $(STAGING_DIR)/usr/bin/mipsel-linux-$(NETPERF_BINARY) $(TARGET_DIR)/usr/bin/$(NETPERF_BINARY)
	-$(STRIP) --strip-unneeded $(TARGET_DIR)/usr/local/bin/$(NETPERF_BINARY)
	cp -a $(STAGING_DIR)/usr/share/pixmaps $(TARGET_DIR)/usr/share/
	mkdir -p $(TARGET_DIR)/usr/info/
	cp -a $(STAGING_DIR)/usr/info/netperf.info $(TARGET_DIR)/usr/info/

netperf: $(TARGET_DIR)/usr/bin/$(NETPERF_BINARY)

netperf-clean:
	-make -C $(NETPERF_DIR) clean

netperf-dirclean:
	rm -rf $(NETPERF_DIR)

#############################################################
#
# Toplevel Makefile options
#
#############################################################
ifeq ($(strip $(BR2_PACKAGE_NETPERF)),y)
TARGETS+=netperf
endif

