#############################################################
#
# directfb
#
#############################################################
DIRECTFB_VERSION:=1.0.0
DIRECTFB_SOURCE:=DirectFB-$(DIRECTFB_VERSION)_nxp.tar.gz
DIRECTFB_SITE:=http://www.directfb.org/downloads/Core
DIRECTFB_CAT:=zcat
DIRECTFB_DIR:=$(BUILD_DIR)/DirectFB-$(DIRECTFB_VERSION)_nxp

# TRACING_AND_DEBUG_ENABLE:= --enable-debug --enable-trace

FUSION_VERSION:=3.2.3

$(DL_DIR)/$(DIRECTFB_SOURCE):
	$(WGET) -P $(DL_DIR) $(DIRECTFB_SITE)/$(DIRECTFB_SOURCE)

directfb-source: $(DL_DIR)/$(DIRECTFB_SOURCE)

$(DIRECTFB_DIR)/.unpacked: $(DL_DIR)/$(DIRECTFB_SOURCE)
	$(DIRECTFB_CAT) $(DL_DIR)/$(DIRECTFB_SOURCE) | tar -C $(BUILD_DIR) $(TAR_OPTIONS) -
	rm -f package/directfb/directfb-i830-detect.patch
	touch $(DIRECTFB_DIR)/.unpacked

$(DIRECTFB_DIR)/.patched:$(DIRECTFB_DIR)/.unpacked
	mkdir -p $(DIRECTFB_DIR)/include/fusion/linux
	tar zxfO $(DL_DIR)/linux-fusion-$(FUSION_VERSION).tar.gz \
		linux-fusion-$(FUSION_VERSION)/linux/include/linux/fusion.h > $(DIRECTFB_DIR)/include/fusion/linux/fusion.h
	cp -R package/directfb/overlay/* $(DIRECTFB_DIR)
	toolchain/patch-kernel.sh $(DIRECTFB_DIR) package/directfb/ libdir-la.patch
	touch  $(DIRECTFB_DIR)/.patched

$(DIRECTFB_DIR)/.configured: $(DIRECTFB_DIR)/.patched
	(cd $(DIRECTFB_DIR); \
	$(TARGET_CONFIGURE_OPTS) \
	CFLAGS="$(TARGET_CFLAGS) -I. -I$(DIRECTFB_DIR)/include/fusion -I$(STAGING_DIR)/usr/include -I$(STAGING_DIR)/include" \
	LDFLAGS="-L$(STAGING_DIR)/lib -L$(STAGING_DIR)/usr/lib -Wl,--rpath-link -Wl,$(STAGING_DIR)/lib" \
	ac_cv_header_linux_wm97xx_h=no \
	ac_cv_header_linux_sisfb_h=no \
    ac_cv_header_asm_page_h=no \
	./configure \
	--target=$(GNU_TARGET_NAME) \
	--host=$(GNU_TARGET_NAME) \
	--build=$(GNU_HOST_NAME) \
	--prefix=/usr/local \
	--exec-prefix=/usr/local \
	--bindir=/usr/local/bin \
	--sbindir=/usr/local/sbin \
	--libdir=/usr/local/lib \
	--libexecdir=/usr/local/lib \
	--sysconfdir=/etc \
	--datadir=/usr/local/share \
	--localstatedir=/var \
	--includedir=/usr/local/include \
	--mandir=/usr/local/man \
	--infodir=/usr/local/info \
	--with-gfxdrivers=none \
	--with-inputdrivers=linuxinput,keyboard,ps2mouse \
	--disable-jpeg \
	--disable-png \
	--disable-gif \
	--enable-zlib \
	--disable-sdl \
	--enable-multi \
	--enable-freetype \
	--enable-sysfs \
	--disable-video4linux \
	--disable-video4linux2 \
	$(TRACING_AND_DEBUG_ENABLE) \
	);
	touch  $(DIRECTFB_DIR)/.configured

$(DIRECTFB_DIR)/.compiled: $(DIRECTFB_DIR)/.configured
	$(MAKE) -C $(DIRECTFB_DIR)
	touch $(DIRECTFB_DIR)/.compiled

$(STAGING_DIR)/usr/local/lib/libdirectfb.so: $(DIRECTFB_DIR)/.compiled
	$(MAKE) DESTDIR=$(STAGING_DIR) -C $(DIRECTFB_DIR) install
	$(SED) "/^libdir=/ s,/usr/local/lib,$(STAGING_DIR)/usr/local/lib,g" $(STAGING_DIR)/usr/local/lib/libdirectfb.la
	$(SED) "/^dependency_libs=/ s,/usr/local/lib,$(STAGING_DIR)/usr/local/lib,g" $(STAGING_DIR)/usr/local/lib/libdirectfb.la
	$(SED) "/^libdir=/ s,/usr/local/lib,$(STAGING_DIR)/usr/local/lib,g" $(STAGING_DIR)/usr/local/lib/libdirect.la
	$(SED) "/^dependency_libs=/ s,/usr/local/lib,$(STAGING_DIR)/usr/local/lib,g" $(STAGING_DIR)/usr/local/lib/libdirect.la
	$(SED) "/^libdir=/ s,/usr/local/lib,$(STAGING_DIR)/usr/local/lib,g" $(STAGING_DIR)/usr/local/lib/libfusion.la
	$(SED) "/^dependency_libs=/ s,/usr/local/lib,$(STAGING_DIR)/usr/local/lib,g" $(STAGING_DIR)/usr/local/lib/libfusion.la
	touch -c $(STAGING_DIR)/usr/local/lib/libdirectfb.so

$(TARGET_DIR)/usr/local/lib/libdirectfb.so: $(STAGING_DIR)/usr/local/lib/libdirectfb.so
	mkdir -p $(TARGET_DIR)/usr/local/lib
	mkdir -p $(TARGET_DIR)/usr/local/bin
	mkdir -p $(TARGET_DIR)/usr/local/share/directfb-$(DIRECTFB_VERSION)
	# Copy in the useful DirectFB apps
	cp -dpf $(STAGING_DIR)/usr/local/bin/$(GNU_TARGET_NAME)-dfbdump $(TARGET_DIR)/usr/local/bin/dfbdump
	cp -dpf $(STAGING_DIR)/usr/local/bin/$(GNU_TARGET_NAME)-dfbg $(TARGET_DIR)/usr/local/bin/dfbg
	cp -dpf $(STAGING_DIR)/usr/local/bin/$(GNU_TARGET_NAME)-dfbinfo $(TARGET_DIR)/usr/local/bin/dfbinfo
	cp -dpf $(STAGING_DIR)/usr/local/bin/$(GNU_TARGET_NAME)-dfblayer $(TARGET_DIR)/usr/local/bin/dfblayer
	cp -dpf $(STAGING_DIR)/usr/local/bin/$(GNU_TARGET_NAME)-dfbscreen $(TARGET_DIR)/usr/local/bin/dfbscreen
	cp -dpf $(STAGING_DIR)/usr/local/bin/$(GNU_TARGET_NAME)-dfbsummon $(TARGET_DIR)/usr/local/bin/dfbsummon
	# Copy in the DirectFB libraries
	cp -dpf $(STAGING_DIR)/usr/local/lib/libdirect* $(TARGET_DIR)/usr/local/lib/
	cp -dpf $(STAGING_DIR)/usr/local/lib/libfusion* $(TARGET_DIR)/usr/local/lib/
	cp -rdpf $(STAGING_DIR)/usr/local/lib/directfb-1.0-0 $(TARGET_DIR)/usr/local/lib/
	# Copy in the DirectFB cursor
	cp -rdpf $(STAGING_DIR)/usr/local/share/directfb-$(DIRECTFB_VERSION) $(TARGET_DIR)/usr/local/share/
	# Strip the libraries
	-$(STRIP) --strip-unneeded $(TARGET_DIR)/usr/local/bin/dfbdump
	-$(STRIP) --strip-unneeded $(TARGET_DIR)/usr/local/bin/dfbg
	-$(STRIP) --strip-unneeded $(TARGET_DIR)/usr/local/bin/dfbinfo
	-$(STRIP) --strip-unneeded $(TARGET_DIR)/usr/local/bin/dfblayer
	-$(STRIP) --strip-unneeded $(TARGET_DIR)/usr/local/bin/dfbscreen
	-$(STRIP) --strip-unneeded $(TARGET_DIR)/usr/local/bin/dfbsummon
	-$(STRIP) --strip-unneeded $(TARGET_DIR)/usr/local/lib/libdirect*.so
	-$(STRIP) --strip-unneeded $(TARGET_DIR)/usr/local/lib/libfusion*.so

directfb: uclibc freetype libsysfs zlib $(TARGET_DIR)/usr/local/lib/libdirectfb.so

directfb-clean:
	$(MAKE) DESTDIR=$(TARGET_DIR) CC=$(TARGET_CC) -C $(DIRECTFB_DIR) uninstall
	-$(MAKE) -C $(DIRECTFB_DIR) clean

directfb-dirclean:
	rm -rf $(DIRECTFB_DIR)

#############################################################
#
# Toplevel Makefile options
#
#############################################################
ifeq ($(strip $(BR2_PACKAGE_DIRECTFB)),y)
TARGETS+=directfb
endif
