#############################################################
#
# hal
#
#############################################################
HAL_VER:=0.5.8
HAL_SOURCE:=hal-$(HAL_VER).tar.gz
HAL_SITE:=http://hal.freedesktop.org/releases/
HAL_DIR:=$(BUILD_DIR)/hal-$(HAL_VER)
HAL_CAT:=$(ZCAT)
HAL_BINARY:=hald/hald
HAL_TARGET_BINARY:=usr/sbin/hald

GLIB_CFLAGS:=-I$(STAGING_DIR)/include/glib-2.0 \
	     -I$(STAGING_DIR)/lib/glib/include \
	     -I$(STAGING_DIR)/include
GLIB_LIBS:=$(STAGING_DIR)/lib/libglib-2.0.so	\
	   $(STAGING_DIR)/lib/libgmodule-2.0.so \
	   $(STAGING_DIR)/lib/libgobject-2.0.so \
	   $(STAGING_DIR)/lib/libgthread-2.0.so
DBUS_GLIB_LIBS:=$(STAGING_DIR)/usr/lib/libdbus-glib-1.so

$(DL_DIR)/$(HAL_SOURCE):
	$(WGET) -P $(DL_DIR) $(HAL_SITE)/$(HAL_SOURCE)

hal-source: $(DL_DIR)/$(HAL_SOURCE)

$(HAL_DIR)/.unpacked: $(DL_DIR)/$(HAL_SOURCE)
	$(HAL_CAT) $(DL_DIR)/$(HAL_SOURCE) | tar -C $(BUILD_DIR) $(TAR_OPTIONS) -
	toolchain/patch-kernel.sh $(HAL_DIR) package/hal/ \*.patch
	touch $(HAL_DIR)/.unpacked

# The --with-hwdata bit might not work unless the build system actually has something there too. :(
$(HAL_DIR)/.configured: $(HAL_DIR)/.unpacked /usr/bin/pkg-config
	(cd $(HAL_DIR); rm -rf config.cache; \
		$(TARGET_CONFIGURE_OPTS) \
		CFLAGS="-O2 $(TARGET_CFLAGS) -I$(STAGING_DIR)/lib/glib-2.0/include" \
		LDFLAGS="$(TARGET_LDFLAGS)" \
		GLIB_CFLAGS="$(GLIB_CFLAGS)" \
		GLIB_LIBS="$(GLIB_LIBS)" \
		DBUS_CFLAGS="-I$(STAGING_DIR)/usr/include/dbus-1.0 -I$(STAGING_DIR)/usr/lib/dbus-1.0/include" \
		DBUS_LIBS="$(STAGING_DIR)/usr/lib/libdbus-1.so" \
		VOLUME_ID_CFLAGS="$(TARGET_CFLAGS)" \
		VOLUME_ID_LIBS="$(STAGING_DIR)/usr/lib/libvolume_id.so" \
		PKG_CONFIG=/usr/bin/pkg-config \
		ac_cv_path_LIBUSB_CONFIG= \
		./configure \
		--target=$(GNU_TARGET_NAME) \
		--host=$(GNU_TARGET_NAME) \
		--build=$(GNU_HOST_NAME) \
		--prefix=/usr \
		--datadir=/usr/share \
		--sysconfdir=/etc \
		--localstatedir=/var \
		--with-hwdata=/usr/share/hwdata \
		--disable-policy-kit \
		--disable-gtk-doc \
		--disable-static \
		--disable-acpi-acpid \
		--disable-acpi-proc \
	);
	touch  $(HAL_DIR)/.configured

$(HAL_DIR)/hald/hald: $(HAL_DIR)/.configured
	$(MAKE) STAGING_DIR="$(STAGING_DIR)" DESTDIR="$(TARGET_DIR)" DBUS_GLIB_LIBS="$(DBUS_GLIB_LIBS)" -C $(HAL_DIR)

# This is a bit of a hack really. We install into staging so that we
# get all the libraries and stuff there but then we have to copy a
# load of stuff into the real rootfs so that it will actually run.
$(TARGET_DIR)/$(HAL_TARGET_BINARY): $(HAL_DIR)/hald/hald
	$(MAKE) STAGING_DIR="$(STAGING_DIR)" DESTDIR="$(STAGING_DIR)" DBUS_GLIB_LIBS="$(DBUS_GLIB_LIBS)" -C $(HAL_DIR) install
	cp -a $(STAGING_DIR)/usr/lib/libhal*.so.1* $(TARGET_DIR)/usr/lib/
	mkdir -p $(TARGET_DIR)/usr/libexec
	cp -a $(STAGING_DIR)/usr/sbin/hal* $(TARGET_DIR)/usr/sbin
	cp -a $(STAGING_DIR)/usr/bin/hal* $(TARGET_DIR)/usr/bin
	cp -a $(STAGING_DIR)/usr/libexec/hal* $(TARGET_DIR)/usr/libexec
	cp -a $(STAGING_DIR)/etc/hal $(TARGET_DIR)/etc/
	cp -a $(HAL_DIR)/fdi/policy/10osvendor/20-storage-methods.fdi $(TARGET_DIR)/etc/hal/fdi/policy/
	mkdir -p $(TARGET_DIR)/etc/dbus-1/system.d
	cp -a $(STAGING_DIR)/etc/dbus-1/system.d/hal* $(TARGET_DIR)/etc/dbus-1/system.d
	cp -a $(STAGING_DIR)/etc/udev/rules.d/90-hal.rules $(TARGET_DIR)/etc/udev/rules.d
	$(INSTALL) -m 0755 -D package/hal/init-hal $(TARGET_DIR)/etc/init.d/S22haldaemon
	-$(STRIP) --strip-unneeded $(TARGET_DIR)/usr/lib/libhal*

hal: uclibc dbus-glib hwdata udev-volume_id $(TARGET_DIR)/$(HAL_TARGET_BINARY)

hal-clean:
	rm -f $(TARGET_DIR)/etc/dbus-1/system.d/hal.conf
	rm -rf $(TARGET_DIR)/etc/hal $(TARGET_DIR)/usr/share/hal
	rm -f $(TARGET_DIR)/etc/init.d/S98haldaemon
	rm -f $(TARGET_DIR)/etc/udev/rules.d/90-hal.rules
	rm -f $(TARGET_DIR)/usr/bin/hal-* $(TARGET_DIR)/usr/bin/lshal
	rm -f $(TARGET_DIR)/usr/sbin/hald
	rm -f $(TARGET_DIR)/usr/libexec/hald-* $(TARGET_DIR)/usr/libexec/hal-*
	rmdir -p --ignore-fail-on-non-empty $(TARGET_DIR)/usr/libexec
	rm -f $(TARGET_DIR)/usr/lib/libhal.so.1*
	rm -f $(TARGET_DIR)/usr/lib/libhal-storage.so.1*
	-$(MAKE) -C $(HAL_DIR) clean

hal-dirclean:
	rm -rf $(HAL_DIR)

#############################################################
#
# Toplevel Makefile options
#
#############################################################
ifeq ($(strip $(BR2_PACKAGE_HAL)),y)
TARGETS+=hal
endif
