#############################################################
#
# Linux kernel targets
#
#############################################################
ifneq ($(filter $(TARGETS),linux),)

# Version of Linux to download and then apply patches to
DOWNLOAD_LINUX_VERSION=2.6.21.3
# Version of Linux AFTER patches
LINUX_VERSION=2.6.21.3

LINUX_FORMAT=vmlinux
LINUX_BINLOC=$(LINUX_FORMAT)

LINUX_DIR=$(BUILD_DIR)/linux-$(LINUX_VERSION)
LINUX_SOURCE=linux-$(DOWNLOAD_LINUX_VERSION).tar.gz
LINUX_SITE=http://www.linux-mips.org/pub/linux/mips/kernel/v2.6/
LINUX_KCONFIG=target/device/Philips/STB810/linux.config
LINUX_KERNEL=$(BUILD_DIR)/buildroot-kernel
LINUX_BUILD=target/device/Philips/STB810

LINUX_KARCH:=$(shell echo $(ARCH) | sed -e 's/i[3-9]86/i386/' \
	-e 's/mipsel/mips/' \
	-e 's/powerpc/ppc/' \
	-e 's/sh[234]/sh/' \
	)
# Used by pcmcia-cs and others
LINUX_SOURCE_DIR=$(LINUX_DIR)

$(DL_DIR)/$(LINUX_SOURCE):
	-mkdir -p $(DL_DIR)
	$(WGET) -P $(DL_DIR) $(LINUX_SITE)/$(LINUX_SOURCE)

$(LINUX_DIR)/.unpacked: $(DL_DIR)/$(LINUX_SOURCE)
	-mkdir -p $(TOOL_BUILD_DIR)
	-(cd $(TOOL_BUILD_DIR); ln -sf $(LINUX_DIR) linux)
	-(cd $(BUILD_DIR); tar zxf $(DL_DIR)/linux-$(LINUX_VERSION).tar.gz)
ifneq ($(DOWNLOAD_LINUX_VERSION),$(LINUX_VERSION))
	# Rename the dir from the downloaded version to the AFTER patch version
	mv -f $(BUILD_DIR)/linux-$(DOWNLOAD_LINUX_VERSION) $(BUILD_DIR)/linux-$(LINUX_VERSION)
endif
	toolchain/patch-kernel.sh $(LINUX_DIR) $(LINUX_BUILD) *.patch
ifneq ($(PRJROOT),)
	cp -a $(PRJROOT)/src/open/linux/overlay/* $(LINUX_DIR)
endif
	touch $(LINUX_DIR)/.unpacked

$(LINUX_KCONFIG):
	@if [ ! -f "$(LINUX_KCONFIG)" ] ; then \
		echo ""; \
		echo "You should create a .config for your kernel"; \
		echo "and install it as $(LINUX_KCONFIG)"; \
		echo ""; \
		sleep 5; \
	fi;

$(LINUX_DIR)/.configured $(BUILD_DIR)/linux/.configured:  $(LINUX_DIR)/.unpacked  $(LINUX_KCONFIG)
	$(SED) "s,^ARCH.*,ARCH=$(LINUX_KARCH),g;" $(LINUX_DIR)/Makefile
	$(SED) "s,^CROSS_COMPILE.*,CROSS_COMPILE=$(KERNEL_CROSS),g;" $(LINUX_DIR)/Makefile
	-cp $(LINUX_KCONFIG) $(LINUX_DIR)/.config
	$(MAKE) PATH=$(TARGET_PATH) -C $(LINUX_DIR) oldconfig include/linux/version.h
	touch $(LINUX_DIR)/.configured

#This is necessary so that a modules.dep file is created so that modprobe can work.
#So we build the kernel here and do a modules_install we then build any modules we want and install them.
#We can then call the kernel build again with a CPIO archive specified which will build in the CPIO archive (which
#will contain a modules.dep file).
$(LINUX_DIR)/.prepared:  $(LINUX_DIR)/.configured
	$(MAKE) PATH=$(TARGET_PATH) -C $(LINUX_DIR) ARCH=mips CROSS_COMPILE=$(TARGET_CROSS) INSTALL_MOD_PATH=$(TARGET_DIR)
	$(MAKE) PATH=$(TARGET_PATH) -C $(LINUX_DIR) ARCH=mips CROSS_COMPILE=$(TARGET_CROSS) INSTALL_MOD_PATH=$(TARGET_DIR) modules_install
	touch $(LINUX_DIR)/.depend_done

$(LINUX_DIR)/.depend_done:  $(LINUX_DIR)/.configured
	$(MAKE) PATH=$(TARGET_PATH) -C $(LINUX_DIR) ARCH=mips CROSS_COMPILE=$(TARGET_CROSS) dep
	touch $(LINUX_DIR)/.depend_done

$(LINUX_DIR)/$(LINUX_BINLOC): $(LINUX_DIR)/.depend_done
	$(MAKE) PATH=$(TARGET_PATH) -C $(LINUX_DIR) ARCH=mips BUILDROOT_INITRAMFS=$(IMAGE).cpio CROSS_COMPILE=$(TARGET_CROSS) INSTALL_MOD_PATH=$(TARGET_DIR) $(LINUX_FORMAT)

$(LINUX_KERNEL): $(LINUX_DIR)/$(LINUX_BINLOC)
	cp -fa $(LINUX_DIR)/$(LINUX_BINLOC) $(LINUX_KERNEL)
ifneq ($(PRJROOT),)
	$(LINUX_BUILD)/mkRomFs $(BUILD_DIR) $(TARGET_CROSS)
endif
	touch -c $(LINUX_KERNEL)

$(STAGING_DIR)/include/linux/version.h: $(LINUX_DIR)/.configured
	mkdir -p $(STAGING_DIR)/include
	tar -ch -C $(LINUX_DIR)/include -f - linux | tar -xf - -C $(STAGING_DIR)/include/
	tar -ch -C $(LINUX_DIR)/include -f - asm | tar -xf - -C $(STAGING_DIR)/include/

linux: $(STAGING_DIR)/include/linux/version.h $(LINUX_KERNEL) $(IMAGE).cpio

linux-source: $(LINUX_DIR)/.prepared

# This has been renamed so we do _NOT_ by default run this on 'make clean'
linuxclean: clean
	rm -f $(LINUX_KERNEL)
	-$(MAKE) PATH=$(TARGET_PATH) -C $(LINUX_DIR) clean

linux-dirclean:
	rm -rf $(LINUX_DIR)

endif

